@@ -125,6 +125,7 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 
 	dialog->priv->login = gnome_db_login_new (NULL);
+	gnome_db_login_set_enable_create_button (GNOME_DB_LOGIN (dialog->priv->login), TRUE);
 	gtk_widget_show (dialog->priv->login);
 	gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->login, TRUE, TRUE, 0);
 	
@@ -222,12 +223,17 @@ gnome_db_login_dialog_get_type (void)
 GtkWidget *
 gnome_db_login_dialog_new (const gchar *title)
 {
+	GdkPixbuf *icon;
 	GnomeDbLoginDialog *dialog;
 
 	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
-	gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+
+	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+	if (icon) {
+		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
+		g_object_unref (icon);
+	}
 
 	return GTK_WIDGET (dialog);
 }
@@ -272,3 +278,18 @@ const gchar *gnome_db_login_dialog_get_password (GnomeDbLoginDialog *dialog)
 	g_return_val_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog), NULL);
 	return gnome_db_login_get_password (GNOME_DB_LOGIN (dialog->priv->login));
 }
+
+/**
+ * gnome_db_login_dialog_get_login_widget
+ * @dialog: A #GnomeDbLoginDialog widget.
+ *
+ * Get the #GnomeDbLogin widget contained in a #GnomeDbLoginDialog.
+ *
+ * Returns: the login widget contained in the dialog.
+ */
+GtkWidget *
+gnome_db_login_dialog_get_login_widget (GnomeDbLoginDialog *dialog)
+{
+	g_return_val_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog), NULL);
+	return dialog->priv->login;
+}
