@@ -381,6 +381,9 @@ gnome_db_new_table_widget (gint rows, gint cols, gboolean homogenous)
 	GtkWidget *table;
 
 	table = gtk_table_new (rows, cols, homogenous);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+        gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+
 	gtk_widget_show (table);
 
 	return table;
